@@ -8,18 +8,16 @@ parent = os.path.dirname(os.path.dirname(os.path.dirname(
 
 sys.path.insert(0, parent)
 
-from django.test.simple import run_tests
+from django.test.simple import DjangoTestSuiteRunner
 from django.conf import settings
 
 def runtests():
-    failures = run_tests([
+    DjangoTestSuiteRunner(failfast=False).run_tests([
         'django_rules.BackendTest',
         'django_rules.RulePermissionTest',
         'django_rules.UtilsTest',
         'django_rules.DecoratorsTest'
         ], verbosity=1, interactive=True)
-    sys.exit(failures)
 
 if __name__ == '__main__':
     runtests()
-
